@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 10806 2018-03-02 04:29:05Z David $
+# $Id: urls.py 10827 2018-03-11 15:11:03Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2018-03-02 12:29:05 +0800 (Fri, 02 Mar 2018) $
-# $Revision: 10806 $
+# $Date: 2018-03-11 23:11:03 +0800 (Sun, 11 Mar 2018) $
+# $Revision: 10827 $
 
 from django.conf.urls import url, patterns
 
@@ -21,11 +21,11 @@ from Theophrastus.editor import views
 
 urlpatterns = patterns('',
     url(r'^templates/(?P<name>[-\w]+)/', views.getTemplate,
-        name='Theophrastus.views.getTemplate'),
+        name='Theophrastus.editor.views.getTemplate'),
     url(r'^upload/display/$', views.uploadFile,
-        name='Theophrastus.views.uploadFile'),
+        name='Theophrastus.editor.views.uploadFile'),
     url(r'^upload/file/$', views.upload,
-        name='Theophrastus.views.upload'),
+        name='Theophrastus.editor.views.upload'),
     url(r'^facebook/feed/complete/$', views.feedComplete,
-        name="Theophrastus.facebook.feed.complete"),
+        name="Theophrastus.editor.facebook.feed.complete"),
 )
