@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 10799 2018-03-01 03:15:51Z David $
+# $Id: models.py 10850 2018-03-17 23:41:09Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2018-03-01 11:15:51 +0800 (Thu, 01 Mar 2018) $
-# $Revision: 10799 $
+# $Date: 2018-03-18 07:41:09 +0800 (Sun, 18 Mar 2018) $
+# $Revision: 10850 $
 
 from emencia.django.newsletter.models import Newsletter, Contact
 
@@ -30,7 +30,7 @@ class Header(models.Model):
         help_text=_('Custom your header content.'))
 
     def __unicode__(self):
-        return _('Header %s') % str(self.id)
+        return _('Header %s' % (str(self.id), )) 
 
     class Meta:
         verbose_name = _('Header')
@@ -46,20 +46,12 @@ class Footer(models.Model):
         help_text=_('Custom your footer content.'))
 
     def __unicode__(self):
-        return _('Footer %s') % str(self.id)
+        return _('Footer %s' % (str(self.id), )) 
 
     class Meta:
         verbose_name = _('Footer')
         verbose_name_plural = _('Footers')
 
-class ErrorMessage(models.Model):
-
-    message =  models.CharField(max_length=2048, blank=True, null=True)
-
-    newsletter = models.ForeignKey(Newsletter, verbose_name=_('newsletter'))
-
-    contact = models.ForeignKey(Contact, verbose_name=_('contact'))
-
 # Newsletter track links patch, originally stored in Theophrastus/Patch.py
 from emencia.django.newsletter.utils import newsletter
 from Theophrastus.Utility import trackLinks
