@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: generate_test_data.py 10083 2017-07-04 08:36:29Z David $
+# $Id: generate_test_data.py 10797 2018-03-01 02:31:02Z David $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-07-04 16:36:29 +0800 (二, 04  7 2017) $
-# $Revision: 10083 $
+# $Date: 2018-03-01 10:31:02 +0800 (Thu, 01 Mar 2018) $
+# $Revision: 10797 $
 
 import datetime
 import random
@@ -61,8 +61,9 @@ def createStatTestData(contactNum=100, testContactNum=5, testDays=15,
                     The default value is 90.
     """
     
-    from Theophrastus.models import Contact, MailingList, Newsletter, \
-                                    ContactMailingStatus
+    from emencia.django.newsletter.models import Contact, MailingList, \
+                                                 Newsletter, \
+                                                 ContactMailingStatus
     
     def overwriteAutoNow(m):
         for field in m._meta.local_fields:
